# pygp_particle_filter

Once you have cloned this repository, use a terminal to go to its root directory and install the packages with the following command. 

'pip install -e .'

The example jupyter notebook illustrates basic usage. A more full explanation of the functions is covered in University of Southampton FEEG6043: Intelligent Mobile Robotics and the associated tutorial.
